@@ -1,8 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -21,8 +22,8 @@ void *modperl_config_dir_create(apr_pool_t *p, char *dir)
 
     dcfg->location = dir;
 
-    MP_TRACE_d(MP_FUNC, "dir %s\n", dir);
-    
+    MP_TRACE_d(MP_FUNC, "dir %s", dir);
+
 #ifdef USE_ITHREADS
     /* defaults to per-server scope */
     dcfg->interp_scope = MP_INTERP_SCOPE_UNDEF;
@@ -109,7 +110,7 @@ void *modperl_config_dir_merge(apr_pool_t *p, void *basev, void *addv)
         *add  = (modperl_config_dir_t *)addv,
         *mrg  = modperl_config_dir_new(p);
 
-    MP_TRACE_d(MP_FUNC, "basev==0x%lx, addv==0x%lx, mrg==0x%lx\n", 
+    MP_TRACE_d(MP_FUNC, "basev==0x%lx, addv==0x%lx, mrg==0x%lx",
                (unsigned long)basev, (unsigned long)addv,
                (unsigned long)mrg);
 
@@ -139,15 +140,25 @@ void *modperl_config_dir_merge(apr_pool_t *p, void *basev, void *addv)
 
 modperl_config_req_t *modperl_config_req_new(request_rec *r)
 {
-    modperl_config_req_t *rcfg = 
+    modperl_config_req_t *rcfg =
         (modperl_config_req_t *)apr_pcalloc(r->pool, sizeof(*rcfg));
 
-    MP_TRACE_d(MP_FUNC, "0x%lx\n", (unsigned long)rcfg);
+    MP_TRACE_d(MP_FUNC, "0x%lx", (unsigned long)rcfg);
 
     return rcfg;
 }
 
-modperl_config_srv_t *modperl_config_srv_new(apr_pool_t *p)
+modperl_config_con_t *modperl_config_con_new(conn_rec *c)
+{
+    modperl_config_con_t *ccfg =
+        (modperl_config_con_t *)apr_pcalloc(c->pool, sizeof(*ccfg));
+
+    MP_TRACE_d(MP_FUNC, "0x%lx", (unsigned long)ccfg);
+
+    return ccfg;
+}
+
+modperl_config_srv_t *modperl_config_srv_new(apr_pool_t *p, server_rec *s)
 {
     modperl_config_srv_t *scfg = (modperl_config_srv_t *)
         apr_pcalloc(p, sizeof(*scfg));
@@ -171,22 +182,13 @@ modperl_config_srv_t *modperl_config_srv_new(apr_pool_t *p)
 
 #ifdef MP_USE_GTOP
     scfg->gtop = modperl_gtop_new(p);
-#endif        
+#endif
 
-    /* must copy ap_server_argv0, because otherwise any read/write of
-     * $0 corrupts process' argv[0] (visible with 'ps -ef' on most
-     * unices). This is due to the logic of calculating PL_origalen in
-     * perl_parse, which is later used in set_mg.c:Perl_magic_set() to
-     * truncate the argv[0] setting. remember that argv[0] passed to
-     * perl_parse() != process's real argv[0].
-     *
-     * as a copying side-effect, changing $0 now doesn't affect the
-     * way the process is seen from the outside.
-     */
-    modperl_config_srv_argv_push(apr_pstrmemdup(p, ap_server_argv0,
-                                                strlen(ap_server_argv0)));
+    /* make sure httpd's argv[0] is the first argument so $0 is
+     * correctly connected to the real thing */
+    modperl_config_srv_argv_push(s->process->argv[0]);
 
-    MP_TRACE_d(MP_FUNC, "new scfg: 0x%lx\n", (unsigned long)scfg);
+    MP_TRACE_d(MP_FUNC, "new scfg: 0x%lx", (unsigned long)scfg);
 
     return scfg;
 }
@@ -203,7 +205,7 @@ modperl_config_dir_t *modperl_config_dir_new(apr_pool_t *p)
 
     dcfg->SetEnv = apr_table_make(p, 2);
 
-    MP_TRACE_d(MP_FUNC, "new dcfg: 0x%lx\n", (unsigned long)dcfg);
+    MP_TRACE_d(MP_FUNC, "new dcfg: 0x%lx", (unsigned long)dcfg);
 
     return dcfg;
 }
@@ -233,7 +235,7 @@ char **modperl_config_srv_argv_init(modperl_config_srv_t *scfg, int *argc)
 
 void *modperl_config_srv_create(apr_pool_t *p, server_rec *s)
 {
-    modperl_config_srv_t *scfg = modperl_config_srv_new(p);
+    modperl_config_srv_t *scfg = modperl_config_srv_new(p, s);
 
     if (!s->is_virtual) {
 
@@ -251,12 +253,12 @@ void *modperl_config_srv_create(apr_pool_t *p, server_rec *s)
         modperl_init_globals(s, p);
     }
 
-    MP_TRACE_d(MP_FUNC, "p=0x%lx, s=0x%lx, virtual=%d\n",
+    MP_TRACE_d(MP_FUNC, "p=0x%lx, s=0x%lx, virtual=%d",
                p, s, s->is_virtual);
 
 #ifdef USE_ITHREADS
 
-    scfg->interp_pool_cfg = 
+    scfg->interp_pool_cfg =
         (modperl_tipool_config_t *)
         apr_pcalloc(p, sizeof(*scfg->interp_pool_cfg));
 
@@ -282,9 +284,9 @@ void *modperl_config_srv_merge(apr_pool_t *p, void *basev, void *addv)
     modperl_config_srv_t
         *base = (modperl_config_srv_t *)basev,
         *add  = (modperl_config_srv_t *)addv,
-        *mrg  = modperl_config_srv_new(p);
+        *mrg  = modperl_config_srv_new(p, add->server);
 
-    MP_TRACE_d(MP_FUNC, "basev==0x%lx, addv==0x%lx, mrg==0x%lx\n", 
+    MP_TRACE_d(MP_FUNC, "basev==0x%lx, addv==0x%lx, mrg==0x%lx",
                (unsigned long)basev, (unsigned long)addv,
                (unsigned long)mrg);
 
@@ -311,9 +313,7 @@ void *modperl_config_srv_merge(apr_pool_t *p, void *basev, void *addv)
     merge_item(perl);
 #endif
 
-    if (add->argv->nelts == 2 &&
-        strEQ(((char **)add->argv->elts)[1], "+inherit"))
-    {
+    if (MpSrvINHERIT_SWITCHES(add)) {
         /* only inherit base PerlSwitches if explicitly told to */
         mrg->argv = base->argv;
     }
@@ -362,11 +362,6 @@ apr_status_t modperl_config_request_cleanup(pTHX_ request_rec *r)
 
     retval = modperl_callback_per_dir(MP_CLEANUP_HANDLER, r, MP_HOOK_RUN_ALL);
 
-    if (rcfg->pnotes) {
-        SvREFCNT_dec(rcfg->pnotes);
-        rcfg->pnotes = Nullhv;
-    }
-
     /* undo changes to %ENV caused by +SetupEnv, perl-script, or
      * $r->subprocess_env, so the values won't persist  */
     if (MpReqSETUP_ENV(rcfg)) {
@@ -405,7 +400,7 @@ int modperl_config_apply_PerlModule(server_rec *s,
     entries = (char **)scfg->PerlModule->elts;
     for (i = 0; i < scfg->PerlModule->nelts; i++){
         if (modperl_require_module(aTHX_ entries[i], TRUE)){
-            MP_TRACE_d(MP_FUNC, "loaded Perl module %s for server %s\n",
+            MP_TRACE_d(MP_FUNC, "loaded Perl module %s for server %s",
                        entries[i], modperl_server_desc(s,p));
         }
         else {
@@ -430,7 +425,7 @@ int modperl_config_apply_PerlRequire(server_rec *s,
     entries = (char **)scfg->PerlRequire->elts;
     for (i = 0; i < scfg->PerlRequire->nelts; i++){
         if (modperl_require_file(aTHX_ entries[i], TRUE)){
-            MP_TRACE_d(MP_FUNC, "loaded Perl file: %s for server %s\n",
+            MP_TRACE_d(MP_FUNC, "loaded Perl file: %s for server %s",
                        entries[i], modperl_server_desc(s,p));
         }
         else {
@@ -463,14 +458,14 @@ int modperl_config_apply_PerlPostConfigRequire(server_rec *s,
         MP_PERL_CONTEXT_RESTORE;
 
         if (retval) {
-            MP_TRACE_d(MP_FUNC, "loaded Perl file: %s for server %s\n",
+            MP_TRACE_d(MP_FUNC, "loaded Perl file: %s for server %s",
                        requires[i]->file, modperl_server_desc(s, p));
         }
         else {
             ap_log_error(APLOG_MARK, APLOG_ERR, 0, s,
                          "Can't load Perl file: %s for server %s, exiting...",
                          requires[i]->file, modperl_server_desc(s, p));
-            
+
             return FALSE;
         }
     }
@@ -509,6 +504,7 @@ const char *modperl_config_insert(pTHX_ server_rec *s,
                                   apr_pool_t *ptmp,
                                   int override,
                                   char *path,
+                                  int override_options,
                                   ap_conf_vector_t *conf,
                                   SV *lines)
 {
@@ -522,8 +518,16 @@ const char *modperl_config_insert(pTHX_ server_rec *s,
     parms.limited = -1;
     parms.server = s;
     parms.override = override;
-    parms.path = path;
+    parms.path = apr_pstrdup(p, path);
     parms.pool = p;
+#ifdef MP_HTTPD_HAS_OVERRIDE_OPTS
+    if (override_options == MP_HTTPD_OVERRIDE_OPTS_UNSET) {
+        parms.override_opts = MP_HTTPD_OVERRIDE_OPTS_DEFAULT;
+    }
+    else {
+        parms.override_opts = override_options;
+    }
+#endif
 
     if (ptmp) {
         parms.temp_pool = ptmp;
@@ -561,15 +565,20 @@ const char *modperl_config_insert(pTHX_ server_rec *s,
     return errmsg;
 }
 
-const char *modperl_config_insert_parms(pTHX_ cmd_parms *parms, 
+const char *modperl_config_insert_parms(pTHX_ cmd_parms *parms,
                                         SV *lines)
 {
-    return modperl_config_insert(aTHX_ 
-                                 parms->server, 
-                                 parms->pool, 
+    return modperl_config_insert(aTHX_
+                                 parms->server,
+                                 parms->pool,
                                  parms->temp_pool,
-                                 parms->override, 
+                                 parms->override,
                                  parms->path,
+#ifdef MP_HTTPD_HAS_OVERRIDE_OPTS
+                                 parms->override_opts,
+#else
+                                 MP_HTTPD_OVERRIDE_OPTS_UNSET,
+#endif
                                  parms->context,
                                  lines);
 }
@@ -581,29 +590,35 @@ const char *modperl_config_insert_server(pTHX_ server_rec *s, SV *lines)
     apr_pool_t *p = s->process->pconf;
 
     return modperl_config_insert(aTHX_ s, p, NULL, override, NULL,
+                                 MP_HTTPD_OVERRIDE_OPTS_UNSET,
                                  s->lookup_defaults, lines);
 }
 
 const char *modperl_config_insert_request(pTHX_
                                           request_rec *r,
                                           SV *lines,
-                                          int override)
+                                          int override,
+                                          char *path,
+                                          int override_options)
 {
     const char *errmsg;
     ap_conf_vector_t *dconf = ap_create_per_dir_config(r->pool);
 
-    /* The path argument of "/" is only required to be non-NULL
-       and "/" is as good a default as anything else */
+    if (!path) {
+        /* pass a non-NULL path if nothing else given and for compatibility */
+        path = "/";
+    }
+
     errmsg = modperl_config_insert(aTHX_
                                    r->server, r->pool, r->pool,
-                                   override, "/",
+                                   override, path, override_options,
                                    dconf, lines);
 
     if (errmsg) {
         return errmsg;
     }
 
-    r->per_dir_config = 
+    r->per_dir_config =
         ap_merge_per_dir_configs(r->pool,
                                  r->per_dir_config,
                                  dconf);
@@ -619,7 +634,6 @@ int modperl_config_is_perl_option_enabled(pTHX_ request_rec *r,
                                           server_rec *s, const char *name)
 {
     U32 flag;
-    MP_dSCFG(s);
 
     /* XXX: should we test whether perl is disabled for this server? */
     /*  if (!MpSrvENABLE(scfg)) { */
@@ -627,7 +641,7 @@ int modperl_config_is_perl_option_enabled(pTHX_ request_rec *r,
     /*  }                         */
 
     if (r) {
-        if ((flag = modperl_flags_lookup_dir(name))) {
+        if ((flag = modperl_flags_lookup_dir(name)) != -1) {
             MP_dDCFG;
             return MpDirFLAGS(dcfg) & flag ? 1 : 0;
         }
@@ -636,7 +650,8 @@ int modperl_config_is_perl_option_enabled(pTHX_ request_rec *r,
         }
     }
     else {
-        if ((flag = modperl_flags_lookup_srv(name))) {
+        if ((flag = modperl_flags_lookup_srv(name)) != -1) {
+            MP_dSCFG(s);
             return MpSrvFLAGS(scfg) & flag ? 1 : 0;
         }
         else {
