@@ -1,8 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -54,7 +55,7 @@ modperl_interp_t *modperl_interp_new(modperl_interp_pool_t *mip,
                                      PerlInterpreter *perl)
 {
     UV clone_flags = CLONEf_KEEP_PTR_TABLE;
-    modperl_interp_t *interp = 
+    modperl_interp_t *interp =
         (modperl_interp_t *)malloc(sizeof(*interp));
 
     memset(interp, '\0', sizeof(*interp));
@@ -78,7 +79,7 @@ modperl_interp_t *modperl_interp_new(modperl_interp_pool_t *mip,
 
         interp->perl = perl_clone(perl, clone_flags);
 
-#if PERL_REVISION == 5 && PERL_VERSION == 8 && PERL_SUBVERSION == 0 && \
+#if MP_PERL_VERSION(5, 8, 0) && \
     defined(USE_REENTRANT_API) && defined(HAS_CRYPT_R) && defined(__GLIBC__)
         {
             dTHXa(interp->perl);
@@ -119,7 +120,7 @@ modperl_interp_t *modperl_interp_new(modperl_interp_pool_t *mip,
 #endif
     }
 
-    MP_TRACE_i(MP_FUNC, "0x%lx / perl: 0x%lx / parent perl: 0x%lx\n",
+    MP_TRACE_i(MP_FUNC, "0x%lx / perl: 0x%lx / parent perl: 0x%lx",
                (unsigned long)interp, (unsigned long)interp->perl,
                (unsigned long)perl);
 
@@ -133,11 +134,11 @@ void modperl_interp_destroy(modperl_interp_t *interp)
 
     PERL_SET_CONTEXT(interp->perl);
 
-    MP_TRACE_i(MP_FUNC, "interp == 0x%lx / perl: 0x%lx\n",
+    MP_TRACE_i(MP_FUNC, "interp == 0x%lx / perl: 0x%lx",
                (unsigned long)interp, (unsigned long)interp->perl);
 
     if (MpInterpIN_USE(interp)) {
-        MP_TRACE_i(MP_FUNC, "*error - still in use!*\n");
+        MP_TRACE_i(MP_FUNC, "*error - still in use!*");
     }
 
     handles = modperl_xs_dl_handles_get(aTHX);
@@ -165,16 +166,16 @@ modperl_interp_t *modperl_interp_get(server_rec *s)
     head = modperl_tipool_pop(mip->tipool);
     interp = (modperl_interp_t *)head->data;
 
-    MP_TRACE_i(MP_FUNC, "head == 0x%lx, parent == 0x%lx\n",
+    MP_TRACE_i(MP_FUNC, "head == 0x%lx, parent == 0x%lx",
                (unsigned long)head, (unsigned long)mip->parent);
 
-    MP_TRACE_i(MP_FUNC, "selected 0x%lx (perl==0x%lx)\n",
+    MP_TRACE_i(MP_FUNC, "selected 0x%lx (perl==0x%lx)",
                (unsigned long)interp,
                (unsigned long)interp->perl);
 
 #ifdef MP_TRACE
     interp->tid = MP_TIDF;
-    MP_TRACE_i(MP_FUNC, "thread == 0x%lx\n", interp->tid);
+    MP_TRACE_i(MP_FUNC, "thread == 0x%lx", interp->tid);
 #endif
 
     MpInterpIN_USE_On(interp);
@@ -195,7 +196,7 @@ apr_status_t modperl_interp_pool_destroy(void *data)
         /* multiple mips might share the same parent
          * make sure its only destroyed once
          */
-        MP_TRACE_i(MP_FUNC, "parent == 0x%lx\n",
+        MP_TRACE_i(MP_FUNC, "parent == 0x%lx",
                    (unsigned long)mip->parent);
 
         modperl_interp_destroy(mip->parent);
@@ -207,7 +208,7 @@ apr_status_t modperl_interp_pool_destroy(void *data)
 static void *interp_pool_grow(modperl_tipool_t *tipool, void *data)
 {
     modperl_interp_pool_t *mip = (modperl_interp_pool_t *)data;
-    MP_TRACE_i(MP_FUNC, "adding new interpreter to the pool\n");
+    MP_TRACE_i(MP_FUNC, "adding new interpreter to the pool");
     return (void *)modperl_interp_new(mip, mip->parent->perl);
 }
 
@@ -222,7 +223,7 @@ static void interp_pool_dump(modperl_tipool_t *tipool, void *data,
 {
     while (listp) {
         modperl_interp_t *interp = (modperl_interp_t *)listp->data;
-        MP_TRACE_i(MP_FUNC, "listp==0x%lx, interp==0x%lx, requests=%d\n",
+        MP_TRACE_i(MP_FUNC, "listp==0x%lx, interp==0x%lx, requests=%d",
                  (unsigned long)listp, (unsigned long)interp,
                  interp->num_requests);
         listp = listp->next;
@@ -243,10 +244,10 @@ void modperl_interp_init(server_rec *s, apr_pool_t *p,
     apr_pool_t *server_pool = modperl_server_pool();
     pTHX;
     MP_dSCFG(s);
-    modperl_interp_pool_t *mip = 
+    modperl_interp_pool_t *mip =
         (modperl_interp_pool_t *)apr_pcalloc(p, sizeof(*mip));
 
-    MP_TRACE_i(MP_FUNC, "server=%s\n", modperl_server_desc(s, p));
+    MP_TRACE_i(MP_FUNC, "server=%s", modperl_server_desc(s, p));
 
     if (modperl_threaded_mpm()) {
         mip->tipool = modperl_tipool_new(p, scfg->interp_pool_cfg,
@@ -274,7 +275,7 @@ apr_status_t modperl_interp_unselect(void *data)
 
     if (interp->refcnt != 0) {
         --interp->refcnt;
-        MP_TRACE_i(MP_FUNC, "interp=0x%lx, refcnt=%d\n",
+        MP_TRACE_i(MP_FUNC, "interp=0x%lx, refcnt=%d",
                    (unsigned long)interp, interp->refcnt);
         return APR_SUCCESS;
     }
@@ -290,7 +291,7 @@ apr_status_t modperl_interp_unselect(void *data)
     MpInterpIN_USE_Off(interp);
     MpInterpPUTBACK_Off(interp);
 
-    MP_THX_INTERP_SET(interp->perl, NULL);
+    modperl_thx_interp_set(interp->perl, NULL);
 
     modperl_tipool_putback_data(mip->tipool, data, interp->num_requests);
 
@@ -342,7 +343,7 @@ modperl_interp_t *modperl_interp_pool_select(apr_pool_t *p,
     modperl_interp_t *interp = NULL;
 
     if (scfg && (is_startup || !modperl_threaded_mpm())) {
-        MP_TRACE_i(MP_FUNC, "using parent interpreter at %s\n",
+        MP_TRACE_i(MP_FUNC, "using parent interpreter at %s",
                    is_startup ? "startup" : "request time (non-threaded MPM)");
 
         if (!scfg->mip) {
@@ -359,11 +360,11 @@ modperl_interp_t *modperl_interp_pool_select(apr_pool_t *p,
             interp = modperl_interp_get(s);
             modperl_interp_pool_set(p, interp, TRUE);
 
-            MP_TRACE_i(MP_FUNC, "set interp in request time pool 0x%lx\n",
+            MP_TRACE_i(MP_FUNC, "set interp in request time pool 0x%lx",
                        (unsigned long)p);
         }
         else {
-            MP_TRACE_i(MP_FUNC, "found interp in request time pool 0x%lx\n",
+            MP_TRACE_i(MP_FUNC, "found interp in request time pool 0x%lx",
                        (unsigned long)p);
         }
     }
@@ -385,7 +386,7 @@ modperl_interp_t *modperl_interp_select(request_rec *r, conn_rec *c,
 
     if (!modperl_threaded_mpm()) {
         MP_TRACE_i(MP_FUNC,
-                   "using parent 0x%lx for non-threaded mpm (%s:%d)\n",
+                   "using parent 0x%lx for non-threaded mpm (%s:%d)",
                    (unsigned long)scfg->mip->parent,
                    s->server_hostname, s->port);
         /* XXX: if no VirtualHosts w/ PerlOptions +Parent we can skip this */
@@ -411,11 +412,11 @@ modperl_interp_t *modperl_interp_select(request_rec *r, conn_rec *c,
      * else scope must be per-connection
      */
 
-    scope = (dcfg && !modperl_interp_scope_undef(dcfg)) ? 
+    scope = (dcfg && !modperl_interp_scope_undef(dcfg)) ?
         dcfg->interp_scope :
         (r ? scfg->interp_scope : MP_INTERP_SCOPE_CONNECTION);
 
-    MP_TRACE_i(MP_FUNC, "scope is per-%s\n",
+    MP_TRACE_i(MP_FUNC, "scope is per-%s",
                modperl_interp_scope_desc(scope));
 
     /*
@@ -447,7 +448,7 @@ modperl_interp_t *modperl_interp_select(request_rec *r, conn_rec *c,
                            "looking for interp in main request for %s...%s\n",
                            main_r->uri, interp ? "found" : "not found");
                 main_r = main_r->main;
-            }                
+            }
         }
         else {
             p = r->pool;
@@ -489,7 +490,7 @@ modperl_interp_t *modperl_interp_select(request_rec *r, conn_rec *c,
     else {
         if (!p) {
             /* should never happen */
-            MP_TRACE_i(MP_FUNC, "no pool\n");
+            MP_TRACE_i(MP_FUNC, "no pool");
             return NULL;
         }
 
@@ -505,7 +506,7 @@ modperl_interp_t *modperl_interp_select(request_rec *r, conn_rec *c,
     /* set context (THX) for this thread */
     PERL_SET_CONTEXT(interp->perl);
 
-    MP_THX_INTERP_SET(interp->perl, interp);
+    modperl_thx_interp_set(interp->perl, interp);
 
     return interp;
 }
@@ -574,6 +575,24 @@ void modperl_interp_mip_walk_servers(PerlInterpreter *current_perl,
     }
 }
 
+#define MP_THX_INTERP_KEY "modperl2::thx_interp_key"
+modperl_interp_t *modperl_thx_interp_get(PerlInterpreter *thx)
+{
+    modperl_interp_t *interp;
+    dTHXa(thx);
+    SV **svp = hv_fetch(PL_modglobal, MP_THX_INTERP_KEY, strlen(MP_THX_INTERP_KEY), 0);
+    if (!svp) return NULL;
+    interp = INT2PTR(modperl_interp_t *, SvIV(*svp));
+    return interp;
+}
+
+void modperl_thx_interp_set(PerlInterpreter *thx, modperl_interp_t *interp)
+{
+    dTHXa(thx);
+    (void)hv_store(PL_modglobal, MP_THX_INTERP_KEY, strlen(MP_THX_INTERP_KEY), newSViv(PTR2IV(interp)), 0);
+    return;
+}
+
 #else
 
 void modperl_interp_init(server_rec *s, apr_pool_t *p,
