@@ -297,8 +297,8 @@ modperl_module_config_create_obj(pTHX_
     }
 
     MP_TRACE_c(MP_FUNC, "%s cfg=0x%lx for %s.%s",
-               method, (unsigned long)cfg,
-               mname, parms->cmd->name);
+               method ? modperl_mgv_last_name(method) : "NULL",
+               (unsigned long)cfg, mname, parms->cmd->name);
 
     /* used by merge functions to get a Perl interp */
     cfg->server = parms->server;
@@ -741,8 +741,6 @@ static const char *modperl_module_add_cmds(apr_pool_t *p, server_rec *s,
 
 static void modperl_module_insert(module *modp)
 {
-    module *m;
-
     /*
      * insert after mod_perl, rather the top of the list.
      * (see ap_add_module; does not insert into ap_top_module list if
@@ -750,14 +748,8 @@ static void modperl_module_insert(module *modp)
      * this way, modperl config merging happens before this module.
      */
 
-    for (m = ap_top_module; m; m=m->next) {
-        if (m == &perl_module) {
-            module *next = m->next;
-            m->next = modp;
-            modp->next = next;
-            break;
-        }
-    }
+    modp->next = perl_module.next;
+    perl_module.next = modp;
 }
 
 #define MP_isGV(gv) (gv && isGV(gv))
