@@ -5,12 +5,12 @@ package TestAPI::lookup_uri;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::Filter ();
-use Apache::SubRequest ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::Filter ();
+use Apache2::SubRequest ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 my $uri = '/' . Apache::TestRequest::module2path(__PACKAGE__);
 
@@ -33,7 +33,7 @@ sub handler {
             $subr = $r->lookup_uri($new_args,
                                    $r->output_filters);
         }
-        if ($args{filter} eq 'second') {
+        elsif ($args{filter} eq 'second') {
             # run all request filters, but the top one
             $subr = $r->lookup_uri($new_args,
                                    $r->output_filters->next);
@@ -48,13 +48,13 @@ sub handler {
                                    $r->proto_output_filters);
         }
         else {
-            # nada
+            die "no filter= argument was received";
         }
 
         $subr->run;
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 sub prefix_filter {
@@ -64,7 +64,7 @@ sub prefix_filter {
         $filter->print("pre+$buffer");
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 sub suffix_filter {
@@ -74,7 +74,7 @@ sub suffix_filter {
         $filter->print("$buffer+suf");
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
