@@ -1,8 +1,9 @@
-/* Copyright 2001-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -85,7 +86,7 @@ static PerlIO *PerlIOAPR_open(pTHX_ PerlIO_funcs *self,
     switch (*mode) {
       case 'a':
         apr_flag = APR_APPEND | APR_CREATE;
-        break; 
+        break;
       case 'w':
         apr_flag = APR_WRITE | APR_CREATE | APR_TRUNCATE;
         break;
@@ -175,7 +176,7 @@ static SSize_t PerlIOAPR_read(pTHX_ PerlIO *f, void *vbuf, Size_t count)
 
     rc = apr_file_read(st->file, vbuf, &count);
 
-    MP_TRACE_o(MP_FUNC, "%db [%s]\n", (int)count,
+    MP_TRACE_o(MP_FUNC, "%db [%s]", (int)count,
                MP_TRACE_STR_TRUNC(st->pool, (char *)vbuf, (int)count));
 
     if (rc == APR_EOF) {
@@ -183,7 +184,7 @@ static SSize_t PerlIOAPR_read(pTHX_ PerlIO *f, void *vbuf, Size_t count)
         return count;
     }
     else if (rc != APR_SUCCESS) {
-        modperl_croak(aTHX_ rc, "APR::PerlIO::read");  
+        modperl_croak(aTHX_ rc, "APR::PerlIO::read");
     }
 
     return count;
@@ -194,7 +195,7 @@ static SSize_t PerlIOAPR_write(pTHX_ PerlIO *f, const void *vbuf, Size_t count)
     PerlIOAPR *st = PerlIOSelf(f, PerlIOAPR);
     apr_status_t rc;
 
-    MP_TRACE_o(MP_FUNC, "%db [%s]\n", (int)count,
+    MP_TRACE_o(MP_FUNC, "%db [%s]", (int)count,
                MP_TRACE_STR_TRUNC(st->pool, (char *)vbuf, (int)count));
 
     rc = apr_file_write(st->file, vbuf, &count);
@@ -293,7 +294,7 @@ static IV PerlIOAPR_close(pTHX_ PerlIO *f)
         apr_file_name_get(&new_path, st->file);
     }
 
-    rc = apr_os_file_get(&os_file, st->file); 
+    rc = apr_os_file_get(&os_file, st->file);
     if (rc != APR_SUCCESS) {
         Perl_croak(aTHX_ "filedes retrieval failed!");
     }
@@ -407,7 +408,7 @@ static PerlIO_funcs PerlIO_APR = {
     PerlIOAPR_read,
     PerlIOBase_unread,
     PerlIOAPR_write,
-    PerlIOAPR_seek, 
+    PerlIOAPR_seek,
     PerlIOAPR_tell,
     PerlIOAPR_close,
     PerlIOAPR_flush,            /* flush */
@@ -474,7 +475,7 @@ PerlIO *modperl_apr_perlio_apr_file_to_PerlIO(pTHX_ apr_file_t *file,
         apr_os_file_t os_file;
 
         /* convert to the OS representation of file */
-        rc = apr_os_file_get(&os_file, file); 
+        rc = apr_os_file_get(&os_file, file);
         if (rc != APR_SUCCESS) {
             croak("filedes retrieval failed!");
         }
@@ -494,10 +495,10 @@ PerlIO *modperl_apr_perlio_apr_file_to_PerlIO(pTHX_ apr_file_t *file,
 static SV *modperl_apr_perlio_PerlIO_to_glob(pTHX_ PerlIO *pio,
                                              modperl_apr_perlio_hook_e type)
 {
-    SV *retval = modperl_perl_gensym(aTHX_ "APR::PerlIO"); 
-    GV *gv = (GV*)SvRV(retval); 
+    SV *retval = modperl_perl_gensym(aTHX_ "APR::PerlIO");
+    GV *gv = (GV*)SvRV(retval);
 
-    gv_IOadd(gv); 
+    gv_IOadd(gv);
 
     switch (type) {
       case MODPERL_APR_PERLIO_HOOK_WRITE:
@@ -552,7 +553,7 @@ static MP_IO_TYPE *modperl_apr_perlio_apr_file_to_PerlIO(pTHX_ apr_file_t *file,
     };
 
     /* convert to the OS representation of file */
-    rc = apr_os_file_get(&os_file, file); 
+    rc = apr_os_file_get(&os_file, file);
     if (rc != APR_SUCCESS) {
         Perl_croak(aTHX_ "filedes retrieval failed!");
     }
@@ -562,8 +563,8 @@ static MP_IO_TYPE *modperl_apr_perlio_apr_file_to_PerlIO(pTHX_ apr_file_t *file,
     /* let's try without the dup, it seems to work fine:
 
        fd = PerlLIO_dup(os_file);
-       MP_TRACE_o(MP_FUNC, "fd old: %d, new %d\n", os_file, fd);
-       if (!(retval = PerlIO_fdopen(fd, mode))) { 
+       MP_TRACE_o(MP_FUNC, "fd old: %d, new %d", os_file, fd);
+       if (!(retval = PerlIO_fdopen(fd, mode))) {
        ...
        }
 
@@ -575,22 +576,22 @@ static MP_IO_TYPE *modperl_apr_perlio_apr_file_to_PerlIO(pTHX_ apr_file_t *file,
 
     */
 
-    if (!(retval = PerlIO_fdopen(os_file, mode))) { 
+    if (!(retval = PerlIO_fdopen(os_file, mode))) {
         PerlLIO_close(fd);
         Perl_croak(aTHX_ "fdopen failed!");
-    } 
+    }
 
     return retval;
 }
 
-SV *modperl_apr_perlio_apr_file_to_glob(pTHX_ apr_file_t *file, 
+SV *modperl_apr_perlio_apr_file_to_glob(pTHX_ apr_file_t *file,
                                         apr_pool_t *pool,
                                         modperl_apr_perlio_hook_e type)
 {
-    SV *retval = modperl_perl_gensym(aTHX_ "APR::PerlIO"); 
-    GV *gv = (GV*)SvRV(retval); 
+    SV *retval = modperl_perl_gensym(aTHX_ "APR::PerlIO");
+    GV *gv = (GV*)SvRV(retval);
 
-    gv_IOadd(gv); 
+    gv_IOadd(gv);
 
     switch (type) {
       case MODPERL_APR_PERLIO_HOOK_WRITE:
@@ -615,4 +616,3 @@ void modperl_apr_perlio_init(pTHX)
 }
 
 #endif /* PERLIO_LAYERS */
-
