@@ -285,6 +285,7 @@ static apr_status_t mpxs_cleanup_run(void *data)
     }
     PUTBACK;
 
+    save_gp(PL_errgv, 1);       /* local *@ */
     count = call_sv(cdata->cv, G_SCALAR|G_EVAL);
 
     SPAGAIN;
@@ -293,6 +294,11 @@ static apr_status_t mpxs_cleanup_run(void *data)
         (void)POPs; /* the return value is ignored */
     }
 
+    if (SvTRUE(ERRSV)) {
+        Perl_warn(aTHX_ "APR::Pool: cleanup died: %s", 
+                  SvPV_nolen(ERRSV));
+    }
+
     PUTBACK;
     FREETMPS;LEAVE;
 
@@ -311,10 +317,6 @@ static apr_status_t mpxs_cleanup_run(void *data)
     }
 #endif
 
-    if (SvTRUE(ERRSV)) {
-        Perl_croak(aTHX_ SvPV_nolen(ERRSV));
-    }
-
     /* the return value is ignored by apr_pool_destroy anyway */
     return APR_SUCCESS;
 }
